@@ -1,10 +1,8 @@
+/* A Bison parser, made by GNU Bison 2.5.  */
 
-/* A Bison parser, made by GNU Bison 2.4.1.  */
-
-/* Skeleton interface for Bison's Yacc-like parsers in C
+/* Bison interface for Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
-   Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -62,32 +60,33 @@
      VAR_PIDFILE = 278,
      VAR_PORT = 279,
      VAR_STATISTICS = 280,
-     VAR_CHROOT = 281,
-     VAR_USERNAME = 282,
-     VAR_ZONESDIR = 283,
-     VAR_XFRDFILE = 284,
-     VAR_DIFFFILE = 285,
-     VAR_XFRD_RELOAD_TIMEOUT = 286,
-     VAR_TCP_QUERY_COUNT = 287,
-     VAR_TCP_TIMEOUT = 288,
-     VAR_IPV4_EDNS_SIZE = 289,
-     VAR_IPV6_EDNS_SIZE = 290,
-     VAR_ZONEFILE = 291,
-     VAR_ZONE = 292,
-     VAR_ALLOW_NOTIFY = 293,
-     VAR_REQUEST_XFR = 294,
-     VAR_NOTIFY = 295,
-     VAR_PROVIDE_XFR = 296,
-     VAR_NOTIFY_RETRY = 297,
-     VAR_OUTGOING_INTERFACE = 298,
-     VAR_ALLOW_AXFR_FALLBACK = 299,
-     VAR_KEY = 300,
-     VAR_ALGORITHM = 301,
-     VAR_SECRET = 302,
-     VAR_AXFR = 303,
-     VAR_UDP = 304,
-     VAR_VERBOSITY = 305,
-     VAR_HIDE_VERSION = 306
+     VAR_ZONESTATSFILE = 281,
+     VAR_CHROOT = 282,
+     VAR_USERNAME = 283,
+     VAR_ZONESDIR = 284,
+     VAR_XFRDFILE = 285,
+     VAR_DIFFFILE = 286,
+     VAR_XFRD_RELOAD_TIMEOUT = 287,
+     VAR_TCP_QUERY_COUNT = 288,
+     VAR_TCP_TIMEOUT = 289,
+     VAR_IPV4_EDNS_SIZE = 290,
+     VAR_IPV6_EDNS_SIZE = 291,
+     VAR_ZONEFILE = 292,
+     VAR_ZONE = 293,
+     VAR_ALLOW_NOTIFY = 294,
+     VAR_REQUEST_XFR = 295,
+     VAR_NOTIFY = 296,
+     VAR_PROVIDE_XFR = 297,
+     VAR_NOTIFY_RETRY = 298,
+     VAR_OUTGOING_INTERFACE = 299,
+     VAR_ALLOW_AXFR_FALLBACK = 300,
+     VAR_KEY = 301,
+     VAR_ALGORITHM = 302,
+     VAR_SECRET = 303,
+     VAR_AXFR = 304,
+     VAR_UDP = 305,
+     VAR_VERBOSITY = 306,
+     VAR_HIDE_VERSION = 307
    };
 #endif
 /* Tokens.  */
@@ -114,32 +113,33 @@
 #define VAR_PIDFILE 278
 #define VAR_PORT 279
 #define VAR_STATISTICS 280
-#define VAR_CHROOT 281
-#define VAR_USERNAME 282
-#define VAR_ZONESDIR 283
-#define VAR_XFRDFILE 284
-#define VAR_DIFFFILE 285
-#define VAR_XFRD_RELOAD_TIMEOUT 286
-#define VAR_TCP_QUERY_COUNT 287
-#define VAR_TCP_TIMEOUT 288
-#define VAR_IPV4_EDNS_SIZE 289
-#define VAR_IPV6_EDNS_SIZE 290
-#define VAR_ZONEFILE 291
-#define VAR_ZONE 292
-#define VAR_ALLOW_NOTIFY 293
-#define VAR_REQUEST_XFR 294
-#define VAR_NOTIFY 295
-#define VAR_PROVIDE_XFR 296
-#define VAR_NOTIFY_RETRY 297
-#define VAR_OUTGOING_INTERFACE 298
-#define VAR_ALLOW_AXFR_FALLBACK 299
-#define VAR_KEY 300
-#define VAR_ALGORITHM 301
-#define VAR_SECRET 302
-#define VAR_AXFR 303
-#define VAR_UDP 304
-#define VAR_VERBOSITY 305
-#define VAR_HIDE_VERSION 306
+#define VAR_ZONESTATSFILE 281
+#define VAR_CHROOT 282
+#define VAR_USERNAME 283
+#define VAR_ZONESDIR 284
+#define VAR_XFRDFILE 285
+#define VAR_DIFFFILE 286
+#define VAR_XFRD_RELOAD_TIMEOUT 287
+#define VAR_TCP_QUERY_COUNT 288
+#define VAR_TCP_TIMEOUT 289
+#define VAR_IPV4_EDNS_SIZE 290
+#define VAR_IPV6_EDNS_SIZE 291
+#define VAR_ZONEFILE 292
+#define VAR_ZONE 293
+#define VAR_ALLOW_NOTIFY 294
+#define VAR_REQUEST_XFR 295
+#define VAR_NOTIFY 296
+#define VAR_PROVIDE_XFR 297
+#define VAR_NOTIFY_RETRY 298
+#define VAR_OUTGOING_INTERFACE 299
+#define VAR_ALLOW_AXFR_FALLBACK 300
+#define VAR_KEY 301
+#define VAR_ALGORITHM 302
+#define VAR_SECRET 303
+#define VAR_AXFR 304
+#define VAR_UDP 305
+#define VAR_VERBOSITY 306
+#define VAR_HIDE_VERSION 307
 
 
 
@@ -148,14 +148,14 @@
 typedef union YYSTYPE
 {
 
-/* Line 1676 of yacc.c  */
+/* Line 2068 of yacc.c  */
 #line 40 "configparser.y"
 
 	char*	str;
 
 
 
-/* Line 1676 of yacc.c  */
+/* Line 2068 of yacc.c  */
 #line 160 "configparser.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
