@@ -140,6 +140,8 @@ struct query;
 #define	MAXRRSPP		10240    /* Maximum number of rr's per packet */
 #define MAX_COMPRESSED_DNAMES	MAXRRSPP /* Maximum number of compressed domains. */
 #define MAX_COMPRESSION_OFFSET  16383	 /* Compression pointers are 14 bit. */
+#define IPV4_MINIMAL_RESPONSE_SIZE 1480	 /* Recommended minimal edns size for IPv4 */
+#define IPV6_MINIMAL_RESPONSE_SIZE 1220	 /* Recommended minimal edns size for IPv6 */
 
 /*
  * Encode RR with OWNER as owner name into QUERY.  Returns the number
@@ -156,7 +158,9 @@ int packet_encode_rr(struct query *query, domain_type *owner, rr_type *rr);
 int packet_encode_rrset(struct query *query,
 			domain_type *owner,
 			rrset_type *rrset,
-			int truncate_rrset);
+			int truncate_rrset,
+			size_t minimal_respsize,
+			int* done);
 
 /*
  * Skip the RR at the current position in PACKET.
