@@ -7,7 +7,7 @@
  *
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -46,11 +46,18 @@ lookup_table_type dns_certificate_types[] = {
 
 /* Taken from RFC 2535, section 7.  */
 lookup_table_type dns_algorithms[] = {
-	{ 1, "RSAMD5" },	/* RFC 2537 */
-	{ 2, "DH" },		/* RFC 2539 */
-	{ 3, "DSA" },		/* RFC 2536 */
+	{ 1, "RSAMD5" },		/* RFC 2537 */
+	{ 2, "DH" },			/* RFC 2539 */
+	{ 3, "DSA" },			/* RFC 2536 */
 	{ 4, "ECC" },
-	{ 5, "RSASHA1" },	/* RFC 3110 */
+	{ 5, "RSASHA1" },		/* RFC 3110 */
+	{ 6, "DSA-NSEC3-SHA1" },	/* RFC 5155 */
+	{ 7, "RSASHA1-NSEC3-SHA1" },	/* RFC 5155 */
+	{ 8, "RSASHA256" },		/* RFC 5702 */
+	{ 10, "RSASHA512" },		/* RFC 5702 */
+	{ 12, "ECC-GOST" },		/* RFC 5933 */
+	{ 13, "ECDSAP256SHA256" },	/* RFC 6605 */
+	{ 14, "ECDSAP384SHA384" },	/* RFC 6605 */
 	{ 252, "INDIRECT" },
 	{ 253, "PRIVATEDNS" },
 	{ 254, "PRIVATEOID" },
@@ -228,13 +235,7 @@ rdata_algorithm_to_string(buffer_type *output, rdata_atom_type rdata,
 	rr_type* ATTR_UNUSED(rr))
 {
 	uint8_t id = *rdata_atom_data(rdata);
-	lookup_table_type *alg
-		= lookup_by_id(dns_algorithms, id);
-	if (alg) {
-		buffer_printf(output, "%s", alg->name);
-	} else {
-		buffer_printf(output, "%u", (unsigned) id);
-	}
+	buffer_printf(output, "%u", (unsigned) id);
 	return 1;
 }
 
