@@ -1,13 +1,13 @@
 /*
  * util.c -- set of various support routines.
  *
- * Copyright (c) 2001-2006, NLnet Labs. All rights reserved.
+ * Copyright (c) 2001-2011, NLnet Labs. All rights reserved.
  *
  * See LICENSE for the license.
  *
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <assert.h>
 #include <ctype.h>
@@ -834,7 +834,13 @@ compare_serial(uint32_t a, uint32_t b)
 uint16_t
 qid_generate(void)
 {
-	return (uint16_t) random();
+#ifdef HAVE_ARC4RANDOM_UNIFORM
+    return (uint16_t) arc4random_uniform(65536);
+#elif HAVE_ARC4RANDOM
+    return (uint16_t) arc4random();
+#else
+    return (uint16_t) random();
+#endif
 }
 
 void
