@@ -10,7 +10,7 @@
 #ifndef XFRD_NOTIFY_H
 #define XFRD_NOTIFY_H
 
-#include <config.h>
+#include "config.h"
 #include "tsig.h"
 #include "netio.h"
 #include "rbtree.h"
