@@ -10,7 +10,7 @@
 #ifndef XFRD_H
 #define XFRD_H
 
-#include <config.h>
+#include "config.h"
 #include "netio.h"
 #include "rbtree.h"
 #include "namedb.h"
