@@ -1,10 +1,8 @@
+/* A Bison parser, made by GNU Bison 2.5.  */
 
-/* A Bison parser, made by GNU Bison 2.4.1.  */
-
-/* Skeleton interface for Bison's Yacc-like parsers in C
+/* Bison interface for Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
-   Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -102,17 +100,18 @@
      T_IPSECKEY = 318,
      T_DHCID = 319,
      T_NSEC3PARAM = 320,
-     DOLLAR_TTL = 321,
-     DOLLAR_ORIGIN = 322,
-     NL = 323,
-     SP = 324,
-     STR = 325,
-     PREV = 326,
-     BITLAB = 327,
-     T_TTL = 328,
-     T_RRCLASS = 329,
-     URR = 330,
-     T_UTYPE = 331
+     T_TLSA = 321,
+     DOLLAR_TTL = 322,
+     DOLLAR_ORIGIN = 323,
+     NL = 324,
+     SP = 325,
+     STR = 326,
+     PREV = 327,
+     BITLAB = 328,
+     T_TTL = 329,
+     T_RRCLASS = 330,
+     URR = 331,
+     T_UTYPE = 332
    };
 #endif
 /* Tokens.  */
@@ -179,17 +178,18 @@
 #define T_IPSECKEY 318
 #define T_DHCID 319
 #define T_NSEC3PARAM 320
-#define DOLLAR_TTL 321
-#define DOLLAR_ORIGIN 322
-#define NL 323
-#define SP 324
-#define STR 325
-#define PREV 326
-#define BITLAB 327
-#define T_TTL 328
-#define T_RRCLASS 329
-#define URR 330
-#define T_UTYPE 331
+#define T_TLSA 321
+#define DOLLAR_TTL 322
+#define DOLLAR_ORIGIN 323
+#define NL 324
+#define SP 325
+#define STR 326
+#define PREV 327
+#define BITLAB 328
+#define T_TTL 329
+#define T_RRCLASS 330
+#define URR 331
+#define T_UTYPE 332
 
 
 
@@ -198,7 +198,7 @@
 typedef union YYSTYPE
 {
 
-/* Line 1676 of yacc.c  */
+/* Line 2068 of yacc.c  */
 #line 50 "zparser.y"
 
 	domain_type	 *domain;
@@ -211,7 +211,7 @@ typedef union YYSTYPE
 
 
 
-/* Line 1676 of yacc.c  */
+/* Line 2068 of yacc.c  */
 #line 216 "zparser.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
